@@ -1,7 +1,12 @@
 #!/bin/sh
 
 #Temporary permission fix
-chown user:users /home/user/.config/savepress
+if [ "`ls -l /home/user/.config/savepress | grep -o "root"`" == "root" ]; then
+	chown user:users /home/user/.config/savepress
+	dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:"unlocked"
+	run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"savepress-editor permission-issue fixed!"
+	exit
+fi
 
 if [ -f /etc/systemui/savepress.xml ]; then {
 	echo "running savepress.."
